@@ -86,7 +86,7 @@ namespace TrayIcon
     Q_ENUM_NS(Style)
 }
 
-class Preferences : public QObject
+class Preferences final : public QObject
 {
     Q_OBJECT
     Q_DISABLE_COPY_MOVE(Preferences)
@@ -121,8 +121,6 @@ public:
     void setStatusbarDisplayed(bool displayed);
     bool isToolbarDisplayed() const;
     void setToolbarDisplayed(bool displayed);
-    bool startMinimized() const;
-    void setStartMinimized(bool b);
     bool isSplashScreenDisabled() const;
     void setSplashScreenDisabled(bool b);
     bool preventFromSuspendWhenDownloading() const;
@@ -144,7 +142,7 @@ public:
     QString getMailNotificationEmail() const;
     void setMailNotificationEmail(const QString &mail);
     QString getMailNotificationSMTP() const;
-    void setMailNotificationSMTP(const QString &smtp_server);
+    void setMailNotificationSMTP(const QString &smtpServer);
     bool getMailNotificationSMTPSSL() const;
     void setMailNotificationSMTPSSL(bool use);
     bool getMailNotificationSMTPAuth() const;
@@ -199,6 +197,8 @@ public:
     void setWebUIBanDuration(std::chrono::seconds duration);
     int getWebUISessionTimeout() const;
     void setWebUISessionTimeout(int timeout);
+    QString getWebAPISessionCookieName() const;
+    void setWebAPISessionCookieName(const QString &cookieName);
 
     // WebUI security
     bool isWebUiClickjackingProtectionEnabled() const;
@@ -253,7 +253,7 @@ public:
     void setUILocked(bool locked);
 
     bool isAutoRunOnTorrentAddedEnabled() const;
-    void setAutoRunOnTorrentAddedEnabled(const bool enabled);
+    void setAutoRunOnTorrentAddedEnabled(bool enabled);
     QString getAutoRunOnTorrentAddedProgram() const;
     void setAutoRunOnTorrentAddedProgram(const QString &program);
     bool isAutoRunOnTorrentFinishedEnabled() const;
@@ -290,17 +290,8 @@ public:
 #ifdef Q_OS_WIN
     bool neverCheckFileAssoc() const;
     void setNeverCheckFileAssoc(bool check = true);
-    static bool isTorrentFileAssocSet();
-    static bool isMagnetLinkAssocSet();
-    static void setTorrentFileAssoc(bool set);
-    static void setMagnetLinkAssoc(bool set);
-#endif
-#ifdef Q_OS_MACOS
-    static bool isTorrentFileAssocSet();
-    static bool isMagnetLinkAssocSet();
-    static void setTorrentFileAssoc();
-    static void setMagnetLinkAssoc();
 #endif
+
     int getTrackerPort() const;
     void setTrackerPort(int port);
     bool isTrackerPortForwardingEnabled() const;
@@ -317,6 +308,8 @@ public:
     void setConfirmRemoveAllTags(bool enabled);
     bool confirmPauseAndResumeAll() const;
     void setConfirmPauseAndResumeAll(bool enabled);
+    bool confirmMergeTrackers() const;
+    void setConfirmMergeTrackers(bool enabled);
 #ifndef Q_OS_MACOS
     bool systemTrayEnabled() const;
     void setSystemTrayEnabled(bool enabled);
@@ -333,6 +326,12 @@ public:
     bool iconsInMenusEnabled() const;
     void setIconsInMenusEnabled(bool enable);
 #endif // Q_OS_MACOS
+    qint64 getTorrentFileSizeLimit() const;
+    void setTorrentFileSizeLimit(qint64 value);
+    int getBdecodeDepthLimit() const;
+    void setBdecodeDepthLimit(int value);
+    int getBdecodeTokenLimit() const;
+    void setBdecodeTokenLimit(int value);
 
     // Stuff that don't appear in the Options GUI but are saved
     // in the same file.
@@ -384,6 +383,8 @@ public:
     bool getTrackerFilterState() const;
     int getTransSelFilter() const;
     void setTransSelFilter(int index);
+    bool getHideZeroStatusFilters() const;
+    void setHideZeroStatusFilters(bool hide);
     QByteArray getTransHeaderState() const;
     void setTransHeaderState(const QByteArray &state);
     bool getRegexAsFilteringPatternForTransferList() const;
@@ -399,6 +400,13 @@ public:
     QList<QNetworkCookie> getNetworkCookies() const;
     void setNetworkCookies(const QList<QNetworkCookie> &cookies);
 
+    bool useProxyForBT() const;
+    void setUseProxyForBT(bool value);
+    bool useProxyForRSS() const;
+    void setUseProxyForRSS(bool value);
+    bool useProxyForGeneralPurposes() const;
+    void setUseProxyForGeneralPurposes(bool value);
+
     // SpeedWidget
     bool isSpeedWidgetEnabled() const;
     void setSpeedWidgetEnabled(bool enabled);
